LnurlAuthToJwtProvider

Struct LnurlAuthToJwtProvider 

pub struct LnurlAuthToJwtProvider { /* private fields */ }
Provides a JWT token based on LNURL Auth.

Implementations

Source

impl LnurlAuthToJwtProvider

pub fn new( parent_key: Xpriv, url: String, default_headers: HashMap<String, String>, ) -> LnurlAuthToJwtProvider

Creates a new JWT provider based on LNURL Auth.

The LNURL Auth keys are derived as children from a hardened parent key, following LUD-05. The hardened parent extended key is given here as an argument, and is suggested to be the m/138' derivation from the wallet master key as in the specification. However, users are free to choose a consistent hardened derivation path.

The LNURL with the challenge will be retrieved by making a request to the given URL. The JWT token will be returned in response to the signed LNURL request under a token field. The given set of headers will be used for LNURL requests, and will also be returned together with the JWT authorization header for VSS requests.